@@ -8,7 +8,7 @@ use warnings;
 # The first version that completely worked with newer versions of Specio.
 use Moose 2.1802 ();
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 1;
 
@@ -26,7 +26,7 @@ Markdent - An event-based Markdown parser toolkit
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 SYNOPSIS
 
@@ -58,8 +58,8 @@ use it.
 If you just want to do some quick Markdown to HTML conversion use either the
 L<Markdent::Simple::Document> or L<Markdent::Simple::Fragment> class.
 
-This distribution also ships with a command line tool called
-L<markdent-html>. See that tool's documentation for details on how to use it.
+This distribution also ships with a command line tool called L<markdent-html>.
+See that tool's documentation for details on how to use it.
 
 =head1 PROCESSING PIPELINES
 
@@ -93,8 +93,8 @@ L<Markdent::CapturedEvents> class.
 
 =head1 CUSTOM DIALECTS
 
-You may also want to implement a custom dialect to add some additional
-features to the parser. Your parser classes will need to consume either the
+You may also want to implement a custom dialect to add some additional features
+to the parser. Your parser classes will need to consume either the
 L<Markdent::Role::Dialect::BlockParser> or the
 L<Markdent::Role::Dialect::SpanParser> role. The best way to understand how a
 dialect is implemented is to look at one of the existing dialect classes:
@@ -117,31 +117,27 @@ interact with the core parser.
 
 =head1 DONATIONS
 
-If you'd like to thank me for the work I've done on this module,
-please consider making a "donation" to me via PayPal. I spend a lot of
-free time creating free software, and would appreciate any support
-you'd care to offer.
+If you'd like to thank me for the work I've done on this module, please
+consider making a "donation" to me via PayPal. I spend a lot of free time
+creating free software, and would appreciate any support you'd care to offer.
 
-Please note that B<I am not suggesting that you must do this> in order
-for me to continue working on this particular software. I will
-continue to do so, inasmuch as I have in the past, for as long as it
-interests me.
+Please note that B<I am not suggesting that you must do this> in order for me
+to continue working on this particular software. I will continue to do so,
+inasmuch as I have in the past, for as long as it interests me.
 
-Similarly, a donation made in this way will probably not make me work
-on this software much more, unless I get so many donations that I can
-consider working on free software full time, which seems unlikely at
-best.
+Similarly, a donation made in this way will probably not make me work on this
+software much more, unless I get so many donations that I can consider working
+on free software full time, which seems unlikely at best.
 
-To donate, log into PayPal and send money to autarch@urth.org or use
-the button on this page:
-L<http://www.urth.org/~autarch/fs-donation.html>
+To donate, log into PayPal and send money to autarch@urth.org or use the button
+on this page: L<http://www.urth.org/~autarch/fs-donation.html>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-markdent@rt.cpan.org>,
-or through the web interface at L<http://rt.cpan.org>.  I will be
-notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
+Please report any bugs or feature requests to C<bug-markdent@rt.cpan.org>, or
+through the web interface at L<http://rt.cpan.org>.  I will be notified, and
+then you'll automatically be notified of progress on your bug as I make
+changes.
 
 Bugs may be submitted at L<https://github.com/houseabsolute/Markdent/issues>.
 
