@@ -4,10 +4,12 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.38';
+our $VERSION = '0.40';
 
 use Markdent::Event::AutoLink;
+use Markdent::Event::EndStrikethrough;
 use Markdent::Event::LineBreak;
+use Markdent::Event::StartStrikethrough;
 
 use Moose::Role;
 
@@ -35,15 +37,27 @@ around _possible_span_matches => sub {
     my @look_for = $self->$orig();
 
     my %open = $self->_open_start_events_for_span( 'code', 'link' );
-    return @look_for
-        if keys %open;
 
-    return (
-        $self->$orig(),
-        'bare_link',
-    );
+    push @look_for, $self->_look_for_strikethrough
+        unless $open{code};
+    push @look_for, 'bare_link'
+        unless $open{link};
+
+    return @look_for;
 };
 
+sub _look_for_strikethrough {
+    my $self = shift;
+
+    my %open = $self->_open_start_events_for_span('strikethrough');
+
+    if ( $open{strikethrough} ) {
+        return ( [ 'strikethrough_end', $open{strikethrough}->delimiter ] );
+    }
+
+    return ('strikethrough_start');
+}
+
 ## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _match_bare_link {
     my $self = shift;
@@ -68,6 +82,37 @@ sub _match_bare_link {
 
     return 1;
 }
+
+sub _match_strikethrough_start {
+    my $self = shift;
+    my $text = shift;
+
+    my ($delim) = $self->_match_delimiter_start( $text, qr/\~\~/ )
+        or return;
+
+    my $event
+        = $self->_make_event( StartStrikethrough => delimiter => $delim );
+
+    $self->_markup_event($event);
+
+    return 1;
+}
+
+sub _match_strikethrough_end {
+    my $self  = shift;
+    my $text  = shift;
+    my $delim = shift;
+
+    $self->_match_delimiter_end( $text, qr/\Q$delim\E/ )
+        or return;
+
+    my $event = $self->_make_event( EndStrikethrough => delimiter => $delim );
+
+    $self->_markup_event($event);
+
+    return 1;
+}
+
 ## use critic
 
 around _text_end_res => sub {
@@ -77,6 +122,7 @@ around _text_end_res => sub {
     return (
         $self->$orig(),
         qr{https?://},
+        qr/\~\~/,
     );
 };
 
@@ -96,7 +142,7 @@ Markdent::Dialect::GitHub::SpanParser - Span parser for GitHub Markdown
 
 =head1 VERSION
 
-version 0.38
+version 0.40
 
 =head1 DESCRIPTION
 
@@ -125,7 +171,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dave Rolsky.
+This software is copyright (c) 2021 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
