@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 use Moose::Role;
 
@@ -34,13 +34,13 @@ Markdent::Dialect::Theory::SpanParser - Span parser for Theory's proposed Markdo
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 DESCRIPTION
 
-This role is applied to a L<Markdent::Parser::SpanParser> in order to allow
-the pipe (|) and colon (:) characters to be backslash-escaped. These are used
-to mark tables, so they need to be escapeable.
+This role is applied to a L<Markdent::Parser::SpanParser> in order to allow the
+pipe (|) and colon (:) characters to be backslash-escaped. These are used to
+mark tables, so they need to be escapeable.
 
 =head1 ROLES
 
